==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/ast.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Almacenamientu non disponible",
    "Storage invalid" : "Almacenamientu inválidu",
    "Unknown error" : "Fallu desconocíu",
    "Unable to set upload directory." : "Nun pue afitase la carpeta de xubida.",
    "Invalid Token" : "Token inválidu",
    "No file was uploaded. Unknown error" : "Nun se xubió dengún ficheru. Fallu desconocíu",
    "There is no error, the file uploaded with success" : "Nun hai dengún fallu, el ficheru xubióse ensin problemes",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "El ficheru xubíu perpasa la direutiva \"upload_max_filesize\" del ficheru php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu perpasa la direutiva \"MAX_FILE_SIZE\" especificada nel formulariu HTML",
    "The uploaded file was only partially uploaded" : "El ficheru xubióse de mou parcial",
    "No file was uploaded" : "Nun se xubió dengún ficheru",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Failed to write to disk" : "Fallu al escribir al discu",
    "Not enough storage available" : "Nun hai abondu espaciu disponible",
    "The target folder has been moved or deleted." : "La carpeta oxetivu movióse o desanicióse.",
    "Upload failed. Could not find uploaded file" : "Xubida fallida.  Nun pudo atopase'l ficheru xubíu.",
    "Upload failed. Could not get file info." : "Falló la xubida.  Nun se pudo obtener la información del ficheru.",
    "Invalid directory." : "Direutoriu non válidu.",
    "Files" : "Ficheros",
    "All files" : "Tolos ficheros",
    "Favorites" : "Favoritos",
    "Home" : "Casa",
    "Close" : "Zarrar",
    "Upload cancelled." : "Xuba encaboxada.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nun pudo xubise {filename}, paez que ye un directoriu o tien 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "El tamañu de ficheru total {size1} perpasa la llende de xuba {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nun hai abondu espaciu llibre, tas xubiendo {size1} pero namái falta {size2}",
    "Could not get result from server." : "Nun pudo obtenese'l resultáu del sirvidor.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La xuba del ficheru ta en progresu. Si dexes agora la páxina, va encaboxase la xuba.",
    "Actions" : "Aiciones",
    "Download" : "Descargar",
    "Rename" : "Renomar",
    "Delete" : "Desaniciar",
    "Disconnect storage" : "Desconeutar almacenamientu",
    "Unshare" : "Dexar de compartir",
    "Details" : "Detalles",
    "Select" : "Esbillar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "Imposible determinar la fecha",
    "This operation is forbidden" : "La operación ta prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esti direutoriu nun ta disponible, por favor verifica'l rexistru o contacta l'alministrador",
    "No entries in this folder match '{filter}'" : "Nun concasa nenguna entrada nesta carpeta '{filter}'",
    "Name" : "Nome",
    "Size" : "Tamañu",
    "Modified" : "Modificáu",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n ficheru","%n ficheros"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "You don’t have permission to upload or create files here" : "Nun tienes permisu pa xubir o crear ficheros equí",
    "_Uploading %n file_::_Uploading %n files_" : ["Xubiendo %n ficheru","Xubiendo %n ficheros"],
    "New" : "Nuevu",
    "\"{name}\" is an invalid file name." : "\"{name}\" ye un nome de ficheru inválidu.",
    "File name cannot be empty." : "El nome de ficheru nun pue quedar baleru.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'almacenamientu de {owner} ta completu, ¡yá nun se pueden anovar o sincronizar ficheros!",
    "Your storage is full, files can not be updated or synced anymore!" : "L'almacenamientu ta completu, ¡yá nun se pueden anovar o sincronizar ficheros!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'almacenamientu de {owner} ta casi completu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "L'almacenamientu ta casi completu ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["concasa '{filter}'","concasa '{filter}'"],
    "Path" : "Camín",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "Favoritos",
    "Favorite" : "Favoritu",
    "Folder" : "Carpeta",
    "New folder" : "Nueva carpeta",
    "{newname} already exists" : "{newname} yá existe",
    "Upload" : "Xubir",
    "An error occurred while trying to update the tags" : "Hebo un fallu mientres s'intentaba actualizar les etiquetes",
    "A new file or folder has been <strong>created</strong>" : "<strong>Creóse</strong> un ficheru o carpeta nuevos",
    "A file or folder has been <strong>changed</strong>" : "<strong>Camudóse</strong> un ficheru o carpeta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Llendar les notificaciones tocantes a creación y cambeos a tos <strong>ficheros favoritos</strong <em>(namás Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Desanicióse</strong> un ficheru o carpeta",
    "A file or folder has been <strong>restored</strong>" : "<strong>Restauróse</strong> un ficheru o carpeta",
    "You created %1$s" : "Creasti %1$s",
    "%2$s created %1$s" : "%2$s creó %1$s",
    "%1$s was created in a public folder" : "Creóse %1$s nuna carpeta pública",
    "You changed %1$s" : "Modificasti %1$s",
    "%2$s changed %1$s" : "%2$s modificó %1$s",
    "You deleted %1$s" : "Desaniciasti %1$s",
    "%2$s deleted %1$s" : "%2$s desanició %1$s",
    "You restored %1$s" : "Recuperóse %1$s",
    "%2$s restored %1$s" : "%2$s recuperó %1$s",
    "Changed by %2$s" : "Modificáu por %2$s",
    "Deleted by %2$s" : "Desaniciáu por %2$s",
    "Restored by %2$s" : "Recuperáu por %2$s",
    "Upload (max. %s)" : "Xuba (máx. %s)",
    "File handling" : "Alministración de ficheros",
    "Maximum upload size" : "Tamañu máximu de xubida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "Settings" : "Axustes",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Usa esta direición <a href=\"%s\" target=\"_blank\">p'acceder a los ficheros a traviés de WebDAV</a>",
    "Cancel upload" : "Encaboxar xuba",
    "No files in here" : "Nun hai nengún ficheru equí",
    "Upload some content or sync with your devices!" : "¡Xuba algún conteníu o sincroniza colos sos preseos!",
    "No entries found in this folder" : "Nenguna entrada en esta carpeta",
    "Select all" : "Esbillar too",
    "Upload too large" : "La xuba ye abondo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los ficheros que tas intentando xubir perpasen el tamañu máximu pa les xubíes de ficheros nesti servidor.",
    "No favorites" : "Nengún favoritu",
    "Files and folders you mark as favorite will show up here" : "Los ficheros y carpetes que marque como favoritos apaecerán equí",
    "Text file" : "Ficheru de testu",
    "New text file.txt" : "Nuevu testu ficheru.txt"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/ast.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Almacenamientu non disponible",
    "Storage invalid" : "Almacenamientu inválidu",
    "Unknown error" : "Fallu desconocíu",
    "Unable to set upload directory." : "Nun pue afitase la carpeta de xubida.",
    "Invalid Token" : "Token inválidu",
    "No file was uploaded. Unknown error" : "Nun se xubió dengún ficheru. Fallu desconocíu",
    "There is no error, the file uploaded with success" : "Nun hai dengún fallu, el ficheru xubióse ensin problemes",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "El ficheru xubíu perpasa la direutiva \"upload_max_filesize\" del ficheru php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu perpasa la direutiva \"MAX_FILE_SIZE\" especificada nel formulariu HTML",
    "The uploaded file was only partially uploaded" : "El ficheru xubióse de mou parcial",
    "No file was uploaded" : "Nun se xubió dengún ficheru",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Failed to write to disk" : "Fallu al escribir al discu",
    "Not enough storage available" : "Nun hai abondu espaciu disponible",
    "The target folder has been moved or deleted." : "La carpeta oxetivu movióse o desanicióse.",
    "Upload failed. Could not find uploaded file" : "Xubida fallida.  Nun pudo atopase'l ficheru xubíu.",
    "Upload failed. Could not get file info." : "Falló la xubida.  Nun se pudo obtener la información del ficheru.",
    "Invalid directory." : "Direutoriu non válidu.",
    "Files" : "Ficheros",
    "All files" : "Tolos ficheros",
    "File could not be found" : "Nun s'atopó el ficheru",
    "Home" : "Casa",
    "Close" : "Zarrar",
    "Favorites" : "Favoritos",
    "Upload cancelled." : "Xuba encaboxada.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nun pudo xubise {filename}, paez que ye un directoriu o tien 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "El tamañu de ficheru total {size1} perpasa la llende de xuba {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nun hai abondu espaciu llibre, tas xubiendo {size1} pero namái falta {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Fallu xubiendo'l ficheru \"{fileName}\": {message}",
    "Could not get result from server." : "Nun pudo obtenese'l resultáu del sirvidor.",
    "Uploading..." : "Xubiendo...",
    "..." : "...",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "Falten {hours}:{minutes}:{seconds} hour{plural_s}",
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "{minutes}:{seconds} minute{plural_s} left" : "Falten {minutes}:{seconds} minute{plural_s} ",
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "{seconds} second{plural_s} left" : "Falten {seconds} second{plural_s}",
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "En cualquier momentu...",
    "Soon..." : "Pronto...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La xuba del ficheru ta en progresu. Si dexes agora la páxina, va encaboxase la xuba.",
    "Actions" : "Aiciones",
    "Download" : "Descargar",
    "Rename" : "Renomar",
    "Delete" : "Desaniciar",
    "Disconnect storage" : "Desconeutar almacenamientu",
    "Unshare" : "Dexar de compartir",
    "Details" : "Detalles",
    "Select" : "Esbillar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "Imposible determinar la fecha",
    "This operation is forbidden" : "La operación ta prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esti direutoriu nun ta disponible, por favor verifica'l rexistru o contacta l'alministrador",
    "Could not move \"{file}\", target exists" : "Nun pudo movese \"{file}\", destín yá esiste",
    "Could not move \"{file}\"" : "Nun pudo movese \"{file}\"",
    "{newName} already exists" : "{newName} yá esiste",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nun pudo renomase \"{fileName}\", yá nun esiste",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nome \"{targetName}\" yá ta n'usu na carpeta \"{dir}\". Por favor, escueyi un nome diferente.",
    "Could not rename \"{fileName}\"" : "Nun pudo renomase \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nun pudo crease'l ficheru \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nun pudo crease'l ficheru \"{file}\" porque yá esiste",
    "Could not create folder \"{dir}\"" : "Nun pudo crease la carpeta \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "Nun pudo crease la carpeta \"{dir}\" porque yá esiste",
    "Error deleting file \"{fileName}\"." : "Fallu borrando'l ficheru \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "Nun concasa nenguna entrada nesta carpeta '{filter}'",
    "Name" : "Nome",
    "Size" : "Tamañu",
    "Modified" : "Modificáu",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n ficheru","%n ficheros"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "You don’t have permission to upload or create files here" : "Nun tienes permisu pa xubir o crear ficheros equí",
    "_Uploading %n file_::_Uploading %n files_" : ["Xubiendo %n ficheru","Xubiendo %n ficheros"],
    "New" : "Nuevu",
    "\"{name}\" is an invalid file name." : "\"{name}\" ye un nome de ficheru inválidu.",
    "File name cannot be empty." : "El nome de ficheru nun pue quedar baleru.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'almacenamientu de {owner} ta completu, ¡yá nun se pueden anovar o sincronizar ficheros!",
    "Your storage is full, files can not be updated or synced anymore!" : "L'almacenamientu ta completu, ¡yá nun se pueden anovar o sincronizar ficheros!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'almacenamientu de {owner} ta casi completu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "L'almacenamientu ta casi completu ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["concasa '{filter}'","concasa '{filter}'"],
    "Path" : "Camín",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "Favoritos",
    "Favorite" : "Favoritu",
    "Local link" : "Enllaz llocal",
    "Folder" : "Carpeta",
    "New folder" : "Nueva carpeta",
    "{newname} already exists" : "{newname} yá existe",
    "Upload" : "Xubir",
    "An error occurred while trying to update the tags" : "Hebo un fallu mientres s'intentaba actualizar les etiquetes",
    "A new file or folder has been <strong>created</strong>" : "<strong>Creóse</strong> un ficheru o carpeta nuevos",
    "A file or folder has been <strong>changed</strong>" : "<strong>Camudóse</strong> un ficheru o carpeta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Llendar les notificaciones tocantes a creación y cambeos a tos <strong>ficheros favoritos</strong <em>(namás Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Desanicióse</strong> un ficheru o carpeta",
    "A file or folder has been <strong>restored</strong>" : "<strong>Restauróse</strong> un ficheru o carpeta",
    "You created %1$s" : "Creasti %1$s",
    "%2$s created %1$s" : "%2$s creó %1$s",
    "%1$s was created in a public folder" : "Creóse %1$s nuna carpeta pública",
    "You changed %1$s" : "Modificasti %1$s",
    "%2$s changed %1$s" : "%2$s modificó %1$s",
    "You deleted %1$s" : "Desaniciasti %1$s",
    "%2$s deleted %1$s" : "%2$s desanició %1$s",
    "You restored %1$s" : "Recuperóse %1$s",
    "%2$s restored %1$s" : "%2$s recuperó %1$s",
    "Changed by %2$s" : "Modificáu por %2$s",
    "Deleted by %2$s" : "Desaniciáu por %2$s",
    "Restored by %2$s" : "Recuperáu por %2$s",
    "Upload (max. %s)" : "Xuba (máx. %s)",
    "File handling" : "Alministración de ficheros",
    "Maximum upload size" : "Tamañu máximu de xubida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM pue retrasase 5 minutos pa que los cambeos s'apliquen.",
    "Missing permissions to edit from here." : "Falten permisos pa editar dende equí.",
    "Settings" : "Axustes",
    "Show hidden files" : "Amosar ficheros ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Usa esta direición <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">p'acceder a los dos Ficheros via WebDAV</a>",
    "No files in here" : "Nun hai nengún ficheru equí",
    "Upload some content or sync with your devices!" : "¡Xuba algún conteníu o sincroniza colos sos preseos!",
    "No entries found in this folder" : "Nenguna entrada en esta carpeta",
    "Select all" : "Esbillar too",
    "Upload too large" : "La xuba ye abondo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los ficheros que tas intentando xubir perpasen el tamañu máximu pa les xubíes de ficheros nesti servidor.",
    "No favorites" : "Nengún favoritu",
    "Files and folders you mark as favorite will show up here" : "Los ficheros y carpetes que marque como favoritos apaecerán equí",
    "Text file" : "Ficheru de testu",
    "New text file.txt" : "Nuevu testu ficheru.txt"
},
"nplurals=2; plural=(n != 1);");
